# PogoOCR

![Python package](https://github.com/TrainerDex/PogoOCR/workflows/Python%20package/badge.svg) [![Discord](https://discordapp.com/api/guilds/614101299197378571/widget.png?style=shield)](https://discordapp.com/invite/pdxh7P)

A Python tool for running OCR on Pokémon Screenshots using Google Cloud Vision
